require(lme4)
require(car)
require(emmeans)
require(lmerTest)
require(sjPlot)
require(ggplot2)
require(glmmTMB)
require(Hmisc)


## copy in data to R


trill<-read.table(pipe("pbpaste"),header=TRUE)

## subset to each year

data2020<-trill[which(trill$Year=='2020'),]
data2021<-trill[which(trill$Year=='2021'),]

## model seed number as a function of treatment within each year
#zero-inflation w/ poisson fits better than glm with poisson


pl.mod.seed.2020<-glmmTMB(Seeds~TRT, ziformula=~TRT, data= data2020, family=poisson)

summary(pl.mod.seed.2020)

Anova(pl.mod.seed.2020)

emmeans(pl.mod.seed.2020, pairwise~TRT, regrid='response')

pl.mod.seed.2021<-glmmTMB(Seeds~TRT, ziformula=~TRT, data= data2021, family=poisson)

summary(pl.mod.seed.2021)

Anova(pl.mod.seed.2021)

emmeans(pl.mod.seed.2021, pairwise~TRT, regrid='response')

##generate trait only dataset for generation of phenotypic correlation matrix

corr.data.2020<-data2020[,c(6,7,8,9,10,11,12,13,15,16)]
corr.matrix.2020<-rcorr(as.matrix(corr.data.2020))
corr.matrix.2020$r
corr.matrix.2020$P

corr.data.2021<-data2021[,c(5,6,7,8,9,10,11,12,13,15,16)]
corr.matrix.2021<-rcorr(as.matrix(corr.data.2021))
corr.matrix.2021$r
corr.matrix.2021$P



###Test if traits differ between treatments. 

petsize.2020<-lmer(PetSize~TRT, data= data2020)
height.2020<-lmer(HT~TRT, data= data2020)
petcol.2020<-lmer(ColNum ~TRT, data= data2020)
lfwdth.2020<-lmer(LfWdth ~TRT, data= data2020)

petsize.2021<-lmer(PetSize~TRT, data= data2021)
height.2021<-lmer(HT~TRT, data= data2021)
petcol.2021<-lmer(ColNum ~TRT, data= data2021)
lfwdth.2021<-lmer(LfWdth ~TRT, data= data2021)
flwdate.2021<-lmer(DOFFnum~TRT, data=data2021)

anova(petsize.2020)
anova(height.2020)
anova(petcol.2020)
anova(lfwdth.2020)

anova(petsize.2021)
anova(height.2021)
anova(petcol.2021)
anova(lfwdth.2021)
anova(flwdate.2021)


## Models testing for pollinator-mediated selection on each floral trait independently controlling for vegetative size
##Run models using relative seed number set as fitness using a zero-inflated model with a binomial for zeros v.s. non-zeros and a poisson distribution for non-zeros
##for 2020, poisson is best fit. For 2021, gaussian is best fit. 

mod.sel.pet.2020<-glmmTMB(RelSeeds~TRT*zpetsize+TRT*pet2+ZlfWdth, ziformula=~TRT*zpetsize+TRT*pet2+ZlfWdth, data=data2020, family=poisson)

mod.sel.ht.2020<-glmmTMB(RelSeeds~TRT*ZHt+TRT*ht2+ZlfWdth, ziformula=~TRT* ZHt +TRT*ht2+ZlfWdth, data=data2020, family=poisson)

mod.sel.col.2020<-glmmTMB(RelSeeds~TRT*Zpetcol+TRT*col2+ZlfWdth, ziformula=~TRT*Zpetcol+TRT*col2+ZlfWdth, data=data2020, family=poisson)

mod.sel.coldisc.2020<-glmmTMB(RelSeeds~TRT*colclass2+ZlfWdth, ziformula=~TRT*colclass2+ZlfWdth, data=data2020, family=poisson,)


summary(mod.sel.pet.2020)

summary(mod.sel.ht.2020)

summary(mod.sel.col.2020)

summary(mod.sel.coldisc.2020)

Anova(mod.sel.coldisc.2020, type=3)

emmeans(mod.sel.coldisc.2020, pairwise~TRT*colclass2, regrid='response')


mod.sel.pet.2021<-glmmTMB(RelSeeds~TRT*zpetsize+TRT*pet2+ZlfWdth, ziformula=~TRT*zpetsize+TRT*pet2+ZlfWdth, data=data2021,family=poisson)

mod.sel.ht.2021<-glmmTMB(RelSeeds~TRT* ZHt +TRT* ht2 +ZlfWdth, ziformula=~TRT* ZHt +TRT* ht2 +ZlfWdth, data=data2021,family=poisson)

mod.sel.doff.2021<-glmmTMB(RelSeeds~TRT*reldoff +TRT* doff2 +ZlfWdth, ziformula=~TRT* reldoff +TRT* doff2 +ZlfWdth, data=data2021,family=poisson)

mod.sel.col.2021<-glmmTMB(RelSeeds~TRT*Zpetcol +TRT*col2+ZlfWdth, ziformula=~TRT* Zpetcol +TRT*col2+ZlfWdth, data=data2021,family=poisson)

mod.sel.coldisc.2021<-glmmTMB(RelSeeds~TRT*colclass2+ZlfWdth, ziformula=~TRT*colclass2+ZlfWdth, data=data2021,family=poisson)


summary(mod.sel.pet.2021)

summary(mod.sel.ht.2021)

summary(mod.sel.doff.2021)

summary(mod.sel.coldisc.2021)

Anova(mod.sel.coldisc.2021, type=3)

emmeans(mod.sel.coldisc.2020, pairwise~TRT*colclass2, regrid='response')





## subset selection dataframe by treatment to get selection gradients in each treatment

seln.control.2020<-data2020[which(data2020$TRT=='C'),]
seln.supp.2020<-data2020[which(data2020$TRT=='S'),]

seln.control.2021<-data2021[which(data2021$TRT=='C'),]
seln.supp.2021<-data2021[which(data2021$TRT=='S'),]




mod.sel.pet.c.2020<-glmmTMB(RelSeeds~zpetsize+pet2+ZlfWdth, ziformula=~zpetsize+pet2+ZlfWdth, data= seln.control.2020, family=poisson)

mod.sel.pet.s.2020<-glmmTMB(RelSeeds~zpetsize+pet2+ZlfWdth, ziformula=~zpetsize+pet2+ ZlfWdth, data= seln.supp.2020, family=poisson)

mod.sel.ht.c.2020<-glmmTMB(RelSeeds~ ZHt +ht2+ZlfWdth, ziformula=~ZHt +ht2+ZlfWdth, data= seln.control.2020, family=poisson)

mod.sel.ht.s.2020<-glmmTMB(RelSeeds~ ZHt +ht2+ZlfWdth, ziformula=~ZHt +ht2+ZlfWdth, data= seln.supp.2020, family=poisson)


mod.sel.col.c.2020<-glmmTMB(RelSeeds~ colclass2+ZlfWdth, ziformula=~colclass2+ZlfWdth, data= seln.control.2020, family=poisson)

mod.sel.col.s.2020<-glmmTMB(RelSeeds~ colclass2+ZlfWdth, ziformula=~colclass2+ZlfWdth, data= seln.supp.2020, family=poisson)


summary(mod.sel.pet.c.2020)
summary(mod.sel.pet.s.2020)
summary(mod.sel.ht.c.2020)
summary(mod.sel.ht.s.2020)
summary(mod.sel.col.c.2020)
summary(mod.sel.col.s.2020)


mod.sel.pet.c.2021<-glmmTMB(RelSeeds~zpetsize+pet2+ZlfWdth, ziformula=~zpetsize+pet2+ ZlfWdth, data= seln.control.2021,family=poisson)

mod.sel.pet.s.2021<-glmmTMB(RelSeeds~zpetsize+pet2+ZlfWdth, ziformula=~zpetsize+pet2+ ZlfWdth, data= seln.supp.2021,family=poisson)

mod.sel.ht.c.2021<-glmmTMB(RelSeeds~ ZHt +ht2+ZlfWdth, ziformula=~ZHt +ht2+ ZlfWdth, data= seln.control.2021,family= poisson)

mod.sel.ht.s.2021<-glmmTMB(RelSeeds~ ZHt +ht2+ZlfWdth, ziformula=~ZHt +ht2+ ZlfWdth, data= seln.supp.2021,family= poisson)

mod.sel.doff.c.2021<-glmmTMB(RelSeeds~ reldoff+doff2+ZlfWdth, ziformula=~reldoff+doff2+ZlfWdth, data= seln.control.2021,family= poisson)

mod.sel.doff.s.2021<-glmmTMB(RelSeeds~ reldoff+doff2+ZlfWdth, ziformula=~reldoff+doff2+ZlfWdth, data= seln.supp.2021,family= poisson)


mod.sel.col.c.2021<-glmmTMB(RelSeeds~ colclass2+ZlfWdth, ziformula=~colclass2+ZlfWdth, data= seln.control.2021,family= poisson)

mod.sel.col.s.2021<-glmmTMB(RelSeeds~ colclass2+ZlfWdth, ziformula=~colclass2+ZlfWdth, data= seln.supp.2021,family= poisson)



summary(mod.sel.pet.c.2021)
summary(mod.sel.pet.s.2021)
summary(mod.sel.ht.c.2021)
summary(mod.sel.ht.s.2021)
summary(mod.sel.doff.c.2021)
summary(mod.sel.doff.s.2021)
summary(mod.sel.col.c.2021)
summary(mod.sel.col.s.2021)



##Test for antagonist-mediated selection 
mod.sel.pet.herb.2020<-glm(Fruit ~TRT+zpetsize*damage+ZlfWdth,data=data2020, family=binomial)


mod.sel.ht.herb.2020<-glm(Fruit ~TRT+ZHt*damage+ZlfWdth,data=data2020, family=binomial)


mod.sel.col.herb.2020<-glm(Fruit ~TRT+colclass2*damage+ZlfWdth, family=binomial, data=data2020)

summary(mod.sel.pet.herb.2020)
summary(mod.sel.ht.herb.2020)
Anova(mod.sel.col.herb.2020,type=3)


mod.sel.pet.herb.2021<-glm(Fruit ~TRT+zpetsize*damage+ZlfWdth, data=data2021,family=binomial)

mod.sel.ht.herb.2021<-glm(Fruit ~TRT+ZHt*damage+ZlfWdth,data=data2021,family= binomial)

mod.sel.doff.herb.2021<-glm(Fruit~TRT+reldoff*damage+ZlfWdth,  data=data2021,family=binomial)

mod.sel.col.herb.2021<-glm(Fruit ~TRT+colclass2*damage+ZlfWdth,family=poisson, data=data2021)

summary(mod.sel.pet.herb.2021)
summary(mod.sel.ht.herb.2021)
summary(mod.sel.doff.herb.2021)
Anova(mod.sel.col.herb.2021, type=3)
